==> nextcloud-27.1.11.tgz: nextcloud/apps/files_reminders/l10n/en_GB.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "File reminders",
    "Reminder for {name}" : "Reminder for {name}",
    "View file" : "View file",
    "View folder" : "View folder",
    "Set file reminders" : "Set file reminders",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 File reminders**\n\nSet file reminders.",
    "We will remind you of this file" : "We will remind you of this file",
    "Please choose a valid date & time" : "Please choose a valid date & time",
    "Cancel" : "Cancel",
    "Clear reminder" : "Clear reminder",
    "Set reminder" : "Set reminder",
    "Set reminder for \"{fileName}\"" : "Set reminder for \"{fileName}\"",
    "Set reminder at custom date & time" : "Set reminder at custom date & time",
    "Reminder set for \"{fileName}\"" : "Reminder set for \"{fileName}\"",
    "Failed to set reminder" : "Failed to set reminder",
    "Reminder cleared for \"{fileName}\"" : "Reminder cleared for \"{fileName}\"",
    "Failed to clear reminder" : "Failed to clear reminder",
    "Reminder set" : "Reminder set",
    "Set custom reminder" : "Set custom reminder",
    "Later today" : "Later today",
    "Set reminder for later today" : "Set reminder for later today",
    "Tomorrow" : "Tomorrow",
    "Set reminder for tomorrow" : "Set reminder for tomorrow",
    "This weekend" : "This weekend",
    "Set reminder for this weekend" : "Set reminder for this weekend",
    "Next week" : "Next week",
    "Set reminder for next week" : "Set reminder for next week",
    "Back" : "Back",
    "Reminder cleared" : "Reminder cleared",
    "Failed to load reminder" : "Failed to load reminder"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.14.tgz: nextcloud/apps/files_reminders/l10n/en_GB.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "File reminders",
    "Reminder for {name}" : "Reminder for {name}",
    "View file" : "View file",
    "View folder" : "View folder",
    "Set file reminders" : "Set file reminders",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly.",
    "We will remind you of this file" : "We will remind you of this file",
    "Please choose a valid date & time" : "Please choose a valid date & time",
    "Cancel" : "Cancel",
    "Clear reminder" : "Clear reminder",
    "Set reminder" : "Set reminder",
    "Set reminder for \"{fileName}\"" : "Set reminder for \"{fileName}\"",
    "Set reminder at custom date & time" : "Set reminder at custom date & time",
    "Reminder set for \"{fileName}\"" : "Reminder set for \"{fileName}\"",
    "Failed to set reminder" : "Failed to set reminder",
    "Reminder cleared for \"{fileName}\"" : "Reminder cleared for \"{fileName}\"",
    "Failed to clear reminder" : "Failed to clear reminder",
    "Reminder set" : "Reminder set",
    "Set custom reminder" : "Set custom reminder",
    "Later today" : "Later today",
    "Set reminder for later today" : "Set reminder for later today",
    "Tomorrow" : "Tomorrow",
    "Set reminder for tomorrow" : "Set reminder for tomorrow",
    "This weekend" : "This weekend",
    "Set reminder for this weekend" : "Set reminder for this weekend",
    "Next week" : "Next week",
    "Set reminder for next week" : "Set reminder for next week",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 File reminders**\n\nSet file reminders."
},
"nplurals=2; plural=(n != 1);");
